# TheleTTD: Theleruby's OpenTTD Patchpack


## INTRODUCTION

Welcome to TheleTTD!

TheleTTD is an OpenTTD patchpack compiled by Theleruby. It features a small number of unofficial patches (mods) which have been applied to improve the game.

The pack has become smaller over time, as most of the patches have slowly made their way into master or have been replaced with equivalent GRF files.

The patchpack currently includes the following patches:

 * Variable day length from "cargodist with sprinkles"
 * Colour code town names by company rating
 * Long char arrays for text entry boxes
 * Adjustable station naming convention
 * Manual adjustment of infrastructure base costs
 * Manual adjustment of running costs
 * Improved breakdowns patch
 * Manual adjustment of breakdown rates
 * Adjustable town growth factor separately from day length
 * Toggle whether or not inspectors will catch town bribes
 * Station dilapidation
 * Extended save data block

The patchpack is infrequently updated to newer versions of OpenTTD.

Source code is located in a Mercurial repository at https://code.theleruby.com/cpp/openttd-patchpack/source. You may fork it and make any desired changes you wish under the terms of the GNU GENERAL PUBLIC LICENSE Version 2.


## MULTIPLAYER COMPATIBILITY

The patchpack is designed to be compatible with online play. Anyone else who is playing will need an identical version of the patchpack, plus any used NewGRFs.

It is not possible to play with people who have a vanilla/unmodified version of OpenTTD.


## SAVE FILE COMPATIBILITY

Version 6.x of the patchpack is compatible with save files from:

 * Transport Tycoon (DOS version)
 * Transport Tycoon Deluxe (DOS and Windows versions)
 * TTDPatch
 * OpenTTD official builds (up to the last merged master revision)
 * Patchpack version 5.x
 * Patchpack version 6.x (up to the version being used)

It is NOT compatible with save files from patchpack versions 4.x.x or older. It should however correctly identify saves from those versions and prevent you from loading them to avoid save corruption.

Please note that saves from newer versions of the patchpack are unlikely to open with older versions due to save format changes. It is therefore advised always to use the newest patchpack version.

Please also note that to load save files from 5.x you must enable the legacy save file loading support from the settings. This is enabled by default. Since 6.0.0beta2 the legacy save loader no longer interferes with loading normal saves, so it should be safe to leave permanently enabled.


## PRE-COMPILED BINARIES

Each version of the patchpack is compiled as a Win64 binary. The binaries are placed in a Mercurial repository to make updates more convenient.


### If you have Mercurial installed

To download the patchpack binary, point your Mercurial client at:  https://code.theleruby.com/cpp/openttd-patchpack/binaries

Assuming you have not altered the binaries since last download, updates can be applied by doing "hg pull" followed by "hg update tip".
  
It is recommended to use a GUI such as TortoiseHg or SourceTree to perform the update if you are uncomfortable with the command line.


### If you can't be bothered to install Mercurial just for OpenTTD

You may alternatively download a ZIP file of the tip revision from:  https://code.theleruby.com/cpp/openttd-patchpack/binaries/archive/tip.zip

Please be aware that if you do this, you will have no easy-update method and will need to re-download the entire pack manually on each update.


## UPDATING FROM GITHUB MASTER

To update from github master:

 * Run the GitHub Mirror Tool which will mirror the latest changes from GitHub to the master branch on TheleCode
 * Pull the source from TheleCode
 * Merge master branch into patchpack branch
 * Recompile using Visual Studio


## FUTURE CHANGE IDEAS / REQUESTS

Requested by Paul for a future version:

 * Aircraft queueing
 * Reduced tree placement in world gen and reduced tree growth


## CHANGE LOG

### v6.0.1 - 10/May/2022
 * Migrated the patchpack to TheleCode and renamed it to TheleTTD
 * Updated to github revision 867f6a5964379a6974d3960edd92a249056a6fa5

### v6.0.0 - 20/Mar/2022
 * Updated to github revision 8d54f765392654ab634ba3a950c56dd0bf1e7dd9
 * Fixes issue with broken road construction

### v6.0.0beta2 - 20/Mar/2022
 * Updated to github revision 0d9fdeda8e6e90d1af95b455802adaf42a7d2f13
 * Implemented pre-6.x trunk vs patchpack version identification
   (meaning the legacy save loader no longer prevents loading of some trunk saves)
 * Save files from 1.x through 4.x now identify properly and are explicitly blocked loading
 * Fixed broken loading of saves from 5.27932.018 and 5.27932.019

### v6.0.0beta1 - 19/Jan/2022
 * Updated to github revision 523901887827768d6bff347ddb57787b295cc9e1
 * New save format

---

### v5.026 - 15/Jan/2022
 * Updated to github revision eeed3a7613d375f66781f53b42e03729a4ca1c33 from June 2020 (+ cherry picked bug fix)
 * Add the ability to sort station list by dilapidation value
 * Add station dilapidation value to station list (only when enabled, and only for stations with dilapidation above 0)
 * Increase size of vehicle list window to give more space for group names

### v5.025 - 04/Jul/2021
 * Fix issue where breakdowns might cause planes to be stuck at speed 0
 * Fix assert crash trying to check BaNaNaS for missing GRF files when loading saves with large numbers of GRFs

### v5.024 - 28/Apr/2020
 * Updated to github revision 1f1345de098294a4744981d0043512569a35102a
 * Rebranding to Ginever.net OpenTTD Patchpack with attribution update
 * Fix issue with breakdowns patch not respecting crash frequency setting

### v5.023 - 28/Jul/2019
 * Updated to github revision 425cd3e4ca8cf6812bdf015c649a7bf4b76a71a1
 * Fix issue with breakdowns patch multiplying max TE too much

### v5.022 - 21/Jul/2019
 * Updated to github revision 331eba544a4d87ef269043d41951e289a8a16a32
 * Add improved breakdowns patch
 * Add manual adjustment of breakdown rates
 * Add adjustable town growth factor separately from day length
 * Add toggling whether or not inspectors will catch town bribes
 * Add station dilapidation
 * Add increase newgrf limit to 256 with multiplayer support
 * Changed layout of settings GUI to add subgroups to patchpack configuration as it was getting very long
 * Remove station coverage patch as this is now in github

### v5.021 - 16/Jun/2018
 * Updated to github revision 574f547aca42c5c712de98fb424258d45a3ef6df
 * Fix issue introduced in v5.020 where save version 197 would not load

### v5.020 - 06/Jun/2018
 * Updated to github revision 25dbc6542cab0c5a751894317f038b2f7f9ac8c2
 * First version of the patchpack to be based on github release - future version numbers will now drop trunk build number

### v5.27932.019 - 02/Dec/2017
 * Fix string not being updated in US and AU language files
 * Fix bug where saved network passwords were not being reloaded properly in some instances

### v5.27932.018 - 26/Nov/2017
 * Updated to the trunk revision, r27932
 * Added additional expense types to the finances window (only affects future expenses)

### v5.27930.017 - 08/Nov/2017
 * Updated to the trunk revision, r27930

### v5.27500.016 - 20/Jan/2016
 * Updated to the trunk revision, r27500
 * Increased network lag timeout to 60 seconds
 * Increased GRF text table size
 * Improved debugging of 'String too long for destination buffer' error
 * Added plane range multiplier setting
 * Added password saving for dedicated server network games

### v5.27389.015 - 28/Aug/2015
 * Updated to the trunk revision, r27389
 * Fixed station_cmd.cpp crash

### v5.27386.014 - 16/Aug/2015
 * Updated to the trunk revision, r27386

### v5.27099.013 - 28/Dec/2014
 * Updated to the trunk revision, r27099
 * Added new settings which allow the running costs to be adjusted via a multiplier
 * Patchpack settings are now in their own subsection of the settings menu

### v5.26167.012 - 21/Dec/2013
 * Added new settings which allow the infrastructure base costs to be directly adjusted

### v5.26167.011 - 21/Dec/2013
 * Updated to the trunk revision, r26167
 * Added new setting which allows you to change the station naming convention
 * Added coverage button which allows you to view station catchment area coverage after it is placed

### v5.26164.010 - 18/Dec/2013
 * Updated to the trunk revision, r26164
 * Town name colour-coding can now be toggled on or off
 * Town name colour-coding is no longer applied to spectators
 * Town name colour-coding now works for all languages rather than just for English UK
 * The option "show town population in the town name label" now works properly again and works independently of town name colour-coding
 * Day length multiplier now displays in the settings menu correctly, rather than as "(undefined string)"
 * Updated the About dialog

### v5.25942.009-mac - 09/Dec/2013
 * The patchpack is now experimentally available for Mac OS X

### v5.25942.009 - 05/Nov/2013
 * Updated to the trunk revision, r25942

### v5.24771.008b - 02/Dec/2012
 * Updated to the trunk revision, r24771

### v5.24187.007 - 30/Apr/2012
 * Updated to the trunk revision, r24187

### v5.23998.006 - 28/Feb/2012
 * Updated to the trunk revision, r23998
 * Changing the day length factor mid-game no longer causes an assertion failure

### v5.23975.005b - 23/Feb/2012
 * Updated to the trunk revision, r23975

### v5.22434.004 - 08/May/2011
 * Increased the hard-coded length limits of most text boxes

### v5.22434.003 - 08/May/2011
 * Added patchpack information to the About dialog
 * Language string changes (Monorail and Maglev are now Alternate Track 1 and 2)

### v5.22434.002 - 07/May/2011
 * Town names are now colour coded by reputation
   * BLUE - Outstanding/Excellent
   * GREEN - Very Good
   * YELLOW - Good
   * RED - Very Poor/Appalling

### v5.22434.001 - 07/May/2011
 * Re-implemented day length modifier

### v5.22434.000 - 07/May/2011
 * Fresh compile from trunk r22434

---

### v4.20134.006 - 13/Jul/2010
 - Updated to the trunk revision, r20134 (the OpenMSX pitch-bend bug should be fixed now)
 - Added miscellaneous openTTD files that were missing

### v4.20079.005 - 04/Jul/2010
 - Updated to the trunk revision, r20079

### v4.20033.004 - 02/Jul/2010
 - Language support: The game now supports all languages thanks to use of a language merge tool.
   English (US) has been removed to prevent having to maintain two almost-identical language files.

### v4.20033.003 - 30/Jun/2010
 - Reimplemented from 19563.003:  Day length modifier
 - Reimplemented from 19563.003:  Adjustable town passenger/cargo rates
 - Reimplemented from 19563.003:  Daily and weekly autosave
 - Reimplemented from 19563.003:  Vehicle name length increased
 - Reimplemented from 19563.003:  Cargo destinations patch
 - Reimplemented from 19563.003:  Automated timetables and separation

### v4.20033.002 - 30/Jun/2010
 - Reimplemented from 19669.004:  Improved build station GUI

### v4.20033.001 - 30/Jun/2010
 - Reimplemented from 19669.004:  Music track 14 no longer breaks
 - Reimplemented from 19563.002:  Colour-code town names based on reputation
 - Reimplemented from 19563.002:  Alternate rail support

### v4.20033.000 - 30/Jun/2010
 - New compile from trunk r20033 (save games from v1.x, v2.x, and v3.x are no longer compatible)

---

### v3.19669.005 - 18/Apr/2010
 - Implemented watch other companies GUI

### v3.19669.004 - 18/Apr/2010
 - Updated to trunk revision r19669
 - Save games from 19563.003 are still compatible! Woo!
 - Reimplemented "Music track 14 no longer breaks" again
 - Implemented improved build station GUI

### v3.19563.003 - 05/Apr/2010
 - The NewGRF collection shipped with this version has been updated.
 - Reimplemented from 17424.003:  Day length modifier
 - Implemented adjustable town passenger/cargo rates
 - Implemented daily and weekly autosave
 - Implemented vehicle name length increased
 - Implemented cargo destinations patch
 - Implemented automated timetables and separation
 - Fixed a bug with ini.cpp
 - Known issue -- Reimplementation of "Music track 14 no longer breaks" somehow escaped the release of this version

### v3.19563.002 - 05/Apr/2010
 - Reimplemented from 17424.002:  Colour-code town names based on reputation
 - Reimplemented from 17424.004:  Alternate rail support
 - Reimplemented from 17424.004:  Music track 14 no longer breaks

### v3.19563.001 - 05/Apr/2010
 - New compile from trunk r19563 (save games from v1.x and v2.x are no longer compatible)
 - Game updated to support OpenGFX, OpenSFX and OpenMSX betas

---

### v2.17429.005 - 06/Sep/2009
 - Updated to the trunk revision, r17429
 - The in-game credits have been updated

### v2.17424.004 - 05/Sep/2009
 - Reimplemented from 13866.006:  Alternate rail support
 - Fixed issue with 13866.001: Music track 14 "Can't get there from here" no longer breaks
 - The NewGRF collection shipped with this version has been updated.

### v2.17424.003 - 05/Sep/2009
 - Reimplemented from 13866.002:  Day length modifier
 - Fixed issue with 17424.002: Colour codes used are now closer to 14019.007

### v2.17424.002 - 05/Sep/2009
 - Reimplemented from 13866.003:  Colour-code town names based on reputation
 - Language change: English (UK) is now the language shipped with the game rather than English (US)

### v2.17424.001 - 05/Sep/2009
 - New compile from trunk r17424 (save games from v1.x are no longer compatible)
 - Fixed issue with 14019.007: High score table does not save

---

### v1.14019.007 - 08/Aug/2008
 - Updated to the trunk revision, r14019
   Implemented:  Advanced signalling (now in trunk)
 - The NewGRF collection shipped with this version has been updated.

### v1.13866.006 - 30/Jul/2008
 - Implemented:  Alternate rail support

### v1.13866.005 - 30/Jul/2008
 - Minor bug fixes

### v1.13866.004 - 30/Jul/2008
 - Fixed issue with multiplayer game connectivity.

### v1.13866.003 - 29/Jul/2008
 - Implemented:  Colour-code town names based on reputation

### v1.13866.002 - 29/Jul/2008
 - Implemented:  Day length modifier
 - The NewGRF collection shipped with this version has been updated.

### v1.13866.001 - 29/Jul/2008
 - Original compile from trunk r13866